@@ -1,7 +1,8 @@
-from .base import (
+from coupledmodeldriver.configure.forcings.base import (
     ATMESHForcingJSON,
     BestTrackForcingJSON,
     OWIForcingJSON,
     TidalForcingJSON,
     WW3DATAForcingJSON,
+    NationalWaterModelFocringJSON,
 )
